# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetCandidatesResponseDataCandidates(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ats_id': 'str',
        'application_id': 'str',
        'last_name': 'str',
        'parent': 'str',
        'pending_tasks': 'list[str]',
        'job_skills_count': 'float',
        'internal': 'bool',
        'attachments': 'list[GetCandidatesResponseDataAttachments]',
        'email_list': 'list[GetCandidatesResponseDataEmailList]',
        'skills_info': 'str',
        'rating': 'float',
        'current_company': 'GetCandidatesResponseDataCurrentCompany',
        'hiring_manager_review_status': 'GetCandidatesResponseDataHiringManagerReviewStatus',
        'matched_skills': 'float',
        'is_unread': 'bool',
        'first_name': 'str',
        'is_applicant': 'bool',
        'recruiter_forward_info': 'GetCandidatesResponseDataRecruiterForwardInfo',
        'hiring_status': 'GetCandidatesResponseDataHiringStatus',
        'primary_pending_task': 'str',
        'fit_score': 'str',
        'social_profile': 'list[GetCandidatesResponseDataSocialProfile]',
        'candidate_id': 'str',
        'interviews_completed_count': 'float',
        'on_demand_interview_screening': 'GetCandidatesResponseDataOnDemandInterviewScreening',
        'status': 'str'
    }

    attribute_map = {
        'ats_id': 'atsId',
        'application_id': 'applicationId',
        'last_name': 'lastName',
        'parent': 'parent',
        'pending_tasks': 'pendingTasks',
        'job_skills_count': 'jobSkillsCount',
        'internal': 'internal',
        'attachments': 'attachments',
        'email_list': 'emailList',
        'skills_info': 'skillsInfo',
        'rating': 'rating',
        'current_company': 'currentCompany',
        'hiring_manager_review_status': 'hiringManagerReviewStatus',
        'matched_skills': 'matchedSkills',
        'is_unread': 'isUnread',
        'first_name': 'firstName',
        'is_applicant': 'isApplicant',
        'recruiter_forward_info': 'recruiterForwardInfo',
        'hiring_status': 'hiringStatus',
        'primary_pending_task': 'primary_pendingTask',
        'fit_score': 'fitScore',
        'social_profile': 'socialProfile',
        'candidate_id': 'candidateId',
        'interviews_completed_count': 'interviewsCompletedCount',
        'on_demand_interview_screening': 'onDemandInterviewScreening',
        'status': 'status'
    }

    def __init__(self, ats_id=None, application_id=None, last_name=None, parent=None, pending_tasks=None, job_skills_count=None, internal=None, attachments=None, email_list=None, skills_info=None, rating=None, current_company=None, hiring_manager_review_status=None, matched_skills=None, is_unread=None, first_name=None, is_applicant=None, recruiter_forward_info=None, hiring_status=None, primary_pending_task=None, fit_score=None, social_profile=None, candidate_id=None, interviews_completed_count=None, on_demand_interview_screening=None, status=None):  # noqa: E501
        """GetCandidatesResponseDataCandidates - a model defined in Swagger"""  # noqa: E501
        self._ats_id = None
        self._application_id = None
        self._last_name = None
        self._parent = None
        self._pending_tasks = None
        self._job_skills_count = None
        self._internal = None
        self._attachments = None
        self._email_list = None
        self._skills_info = None
        self._rating = None
        self._current_company = None
        self._hiring_manager_review_status = None
        self._matched_skills = None
        self._is_unread = None
        self._first_name = None
        self._is_applicant = None
        self._recruiter_forward_info = None
        self._hiring_status = None
        self._primary_pending_task = None
        self._fit_score = None
        self._social_profile = None
        self._candidate_id = None
        self._interviews_completed_count = None
        self._on_demand_interview_screening = None
        self._status = None
        self.discriminator = None
        if ats_id is not None:
            self.ats_id = ats_id
        if application_id is not None:
            self.application_id = application_id
        if last_name is not None:
            self.last_name = last_name
        if parent is not None:
            self.parent = parent
        if pending_tasks is not None:
            self.pending_tasks = pending_tasks
        if job_skills_count is not None:
            self.job_skills_count = job_skills_count
        if internal is not None:
            self.internal = internal
        if attachments is not None:
            self.attachments = attachments
        if email_list is not None:
            self.email_list = email_list
        if skills_info is not None:
            self.skills_info = skills_info
        if rating is not None:
            self.rating = rating
        if current_company is not None:
            self.current_company = current_company
        if hiring_manager_review_status is not None:
            self.hiring_manager_review_status = hiring_manager_review_status
        if matched_skills is not None:
            self.matched_skills = matched_skills
        if is_unread is not None:
            self.is_unread = is_unread
        if first_name is not None:
            self.first_name = first_name
        if is_applicant is not None:
            self.is_applicant = is_applicant
        if recruiter_forward_info is not None:
            self.recruiter_forward_info = recruiter_forward_info
        if hiring_status is not None:
            self.hiring_status = hiring_status
        if primary_pending_task is not None:
            self.primary_pending_task = primary_pending_task
        if fit_score is not None:
            self.fit_score = fit_score
        if social_profile is not None:
            self.social_profile = social_profile
        if candidate_id is not None:
            self.candidate_id = candidate_id
        if interviews_completed_count is not None:
            self.interviews_completed_count = interviews_completed_count
        if on_demand_interview_screening is not None:
            self.on_demand_interview_screening = on_demand_interview_screening
        if status is not None:
            self.status = status

    @property
    def ats_id(self):
        """Gets the ats_id of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Unique identifier for the candidate in the Applicant Tracking System.  # noqa: E501

        :return: The ats_id of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._ats_id

    @ats_id.setter
    def ats_id(self, ats_id):
        """Sets the ats_id of this GetCandidatesResponseDataCandidates.

        Unique identifier for the candidate in the Applicant Tracking System.  # noqa: E501

        :param ats_id: The ats_id of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: str
        """

        self._ats_id = ats_id

    @property
    def application_id(self):
        """Gets the application_id of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Identifier for the application submitted by the candidate.  # noqa: E501

        :return: The application_id of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """Sets the application_id of this GetCandidatesResponseDataCandidates.

        Identifier for the application submitted by the candidate.  # noqa: E501

        :param application_id: The application_id of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: str
        """

        self._application_id = application_id

    @property
    def last_name(self):
        """Gets the last_name of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Last name of the candidate.  # noqa: E501

        :return: The last_name of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this GetCandidatesResponseDataCandidates.

        Last name of the candidate.  # noqa: E501

        :param last_name: The last_name of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def parent(self):
        """Gets the parent of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Parent collection's database document object id.  # noqa: E501

        :return: The parent of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this GetCandidatesResponseDataCandidates.

        Parent collection's database document object id.  # noqa: E501

        :param parent: The parent of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: str
        """

        self._parent = parent

    @property
    def pending_tasks(self):
        """Gets the pending_tasks of this GetCandidatesResponseDataCandidates.  # noqa: E501

        List of tasks a user can perform on the candidate.  # noqa: E501

        :return: The pending_tasks of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: list[str]
        """
        return self._pending_tasks

    @pending_tasks.setter
    def pending_tasks(self, pending_tasks):
        """Sets the pending_tasks of this GetCandidatesResponseDataCandidates.

        List of tasks a user can perform on the candidate.  # noqa: E501

        :param pending_tasks: The pending_tasks of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: list[str]
        """

        self._pending_tasks = pending_tasks

    @property
    def job_skills_count(self):
        """Gets the job_skills_count of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Number of skills required for the job.  # noqa: E501

        :return: The job_skills_count of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: float
        """
        return self._job_skills_count

    @job_skills_count.setter
    def job_skills_count(self, job_skills_count):
        """Sets the job_skills_count of this GetCandidatesResponseDataCandidates.

        Number of skills required for the job.  # noqa: E501

        :param job_skills_count: The job_skills_count of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: float
        """

        self._job_skills_count = job_skills_count

    @property
    def internal(self):
        """Gets the internal of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Indicates whether the candidate is internal or external.  # noqa: E501

        :return: The internal of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: bool
        """
        return self._internal

    @internal.setter
    def internal(self, internal):
        """Sets the internal of this GetCandidatesResponseDataCandidates.

        Indicates whether the candidate is internal or external.  # noqa: E501

        :param internal: The internal of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: bool
        """

        self._internal = internal

    @property
    def attachments(self):
        """Gets the attachments of this GetCandidatesResponseDataCandidates.  # noqa: E501

        List of attachments to details.  # noqa: E501

        :return: The attachments of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: list[GetCandidatesResponseDataAttachments]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """Sets the attachments of this GetCandidatesResponseDataCandidates.

        List of attachments to details.  # noqa: E501

        :param attachments: The attachments of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: list[GetCandidatesResponseDataAttachments]
        """

        self._attachments = attachments

    @property
    def email_list(self):
        """Gets the email_list of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Array of email addresses details.  # noqa: E501

        :return: The email_list of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: list[GetCandidatesResponseDataEmailList]
        """
        return self._email_list

    @email_list.setter
    def email_list(self, email_list):
        """Sets the email_list of this GetCandidatesResponseDataCandidates.

        Array of email addresses details.  # noqa: E501

        :param email_list: The email_list of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: list[GetCandidatesResponseDataEmailList]
        """

        self._email_list = email_list

    @property
    def skills_info(self):
        """Gets the skills_info of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Matched skills count or job skills count.  # noqa: E501

        :return: The skills_info of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._skills_info

    @skills_info.setter
    def skills_info(self, skills_info):
        """Sets the skills_info of this GetCandidatesResponseDataCandidates.

        Matched skills count or job skills count.  # noqa: E501

        :param skills_info: The skills_info of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: str
        """

        self._skills_info = skills_info

    @property
    def rating(self):
        """Gets the rating of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Overall rating of the candidate.  # noqa: E501

        :return: The rating of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: float
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        """Sets the rating of this GetCandidatesResponseDataCandidates.

        Overall rating of the candidate.  # noqa: E501

        :param rating: The rating of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: float
        """

        self._rating = rating

    @property
    def current_company(self):
        """Gets the current_company of this GetCandidatesResponseDataCandidates.  # noqa: E501


        :return: The current_company of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: GetCandidatesResponseDataCurrentCompany
        """
        return self._current_company

    @current_company.setter
    def current_company(self, current_company):
        """Sets the current_company of this GetCandidatesResponseDataCandidates.


        :param current_company: The current_company of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: GetCandidatesResponseDataCurrentCompany
        """

        self._current_company = current_company

    @property
    def hiring_manager_review_status(self):
        """Gets the hiring_manager_review_status of this GetCandidatesResponseDataCandidates.  # noqa: E501


        :return: The hiring_manager_review_status of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: GetCandidatesResponseDataHiringManagerReviewStatus
        """
        return self._hiring_manager_review_status

    @hiring_manager_review_status.setter
    def hiring_manager_review_status(self, hiring_manager_review_status):
        """Sets the hiring_manager_review_status of this GetCandidatesResponseDataCandidates.


        :param hiring_manager_review_status: The hiring_manager_review_status of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: GetCandidatesResponseDataHiringManagerReviewStatus
        """

        self._hiring_manager_review_status = hiring_manager_review_status

    @property
    def matched_skills(self):
        """Gets the matched_skills of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Number of candidate's skills that match with job skills.  # noqa: E501

        :return: The matched_skills of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: float
        """
        return self._matched_skills

    @matched_skills.setter
    def matched_skills(self, matched_skills):
        """Sets the matched_skills of this GetCandidatesResponseDataCandidates.

        Number of candidate's skills that match with job skills.  # noqa: E501

        :param matched_skills: The matched_skills of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: float
        """

        self._matched_skills = matched_skills

    @property
    def is_unread(self):
        """Gets the is_unread of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Indicates whether the candidate has been read by the user.  # noqa: E501

        :return: The is_unread of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: bool
        """
        return self._is_unread

    @is_unread.setter
    def is_unread(self, is_unread):
        """Sets the is_unread of this GetCandidatesResponseDataCandidates.

        Indicates whether the candidate has been read by the user.  # noqa: E501

        :param is_unread: The is_unread of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: bool
        """

        self._is_unread = is_unread

    @property
    def first_name(self):
        """Gets the first_name of this GetCandidatesResponseDataCandidates.  # noqa: E501

        First name of the candidate.  # noqa: E501

        :return: The first_name of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this GetCandidatesResponseDataCandidates.

        First name of the candidate.  # noqa: E501

        :param first_name: The first_name of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def is_applicant(self):
        """Gets the is_applicant of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Indicates whether the candidate is an applicant or not.  # noqa: E501

        :return: The is_applicant of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: bool
        """
        return self._is_applicant

    @is_applicant.setter
    def is_applicant(self, is_applicant):
        """Sets the is_applicant of this GetCandidatesResponseDataCandidates.

        Indicates whether the candidate is an applicant or not.  # noqa: E501

        :param is_applicant: The is_applicant of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: bool
        """

        self._is_applicant = is_applicant

    @property
    def recruiter_forward_info(self):
        """Gets the recruiter_forward_info of this GetCandidatesResponseDataCandidates.  # noqa: E501


        :return: The recruiter_forward_info of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: GetCandidatesResponseDataRecruiterForwardInfo
        """
        return self._recruiter_forward_info

    @recruiter_forward_info.setter
    def recruiter_forward_info(self, recruiter_forward_info):
        """Sets the recruiter_forward_info of this GetCandidatesResponseDataCandidates.


        :param recruiter_forward_info: The recruiter_forward_info of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: GetCandidatesResponseDataRecruiterForwardInfo
        """

        self._recruiter_forward_info = recruiter_forward_info

    @property
    def hiring_status(self):
        """Gets the hiring_status of this GetCandidatesResponseDataCandidates.  # noqa: E501


        :return: The hiring_status of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: GetCandidatesResponseDataHiringStatus
        """
        return self._hiring_status

    @hiring_status.setter
    def hiring_status(self, hiring_status):
        """Sets the hiring_status of this GetCandidatesResponseDataCandidates.


        :param hiring_status: The hiring_status of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: GetCandidatesResponseDataHiringStatus
        """

        self._hiring_status = hiring_status

    @property
    def primary_pending_task(self):
        """Gets the primary_pending_task of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Primary pending task on the candidate for the user to do with respect to the job.  # noqa: E501

        :return: The primary_pending_task of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._primary_pending_task

    @primary_pending_task.setter
    def primary_pending_task(self, primary_pending_task):
        """Sets the primary_pending_task of this GetCandidatesResponseDataCandidates.

        Primary pending task on the candidate for the user to do with respect to the job.  # noqa: E501

        :param primary_pending_task: The primary_pending_task of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: str
        """
        allowed_values = ["INITIAL_REVIEW", "EVALUATE_INTERVIEW", "FINAL_OFFER"]  # noqa: E501
        if primary_pending_task not in allowed_values:
            raise ValueError(
                "Invalid value for `primary_pending_task` ({0}), must be one of {1}"  # noqa: E501
                .format(primary_pending_task, allowed_values)
            )

        self._primary_pending_task = primary_pending_task

    @property
    def fit_score(self):
        """Gets the fit_score of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Fit score of the candidate for this job.  # noqa: E501

        :return: The fit_score of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._fit_score

    @fit_score.setter
    def fit_score(self, fit_score):
        """Sets the fit_score of this GetCandidatesResponseDataCandidates.

        Fit score of the candidate for this job.  # noqa: E501

        :param fit_score: The fit_score of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: str
        """

        self._fit_score = fit_score

    @property
    def social_profile(self):
        """Gets the social_profile of this GetCandidatesResponseDataCandidates.  # noqa: E501

        List of social profiles of the candidate.  # noqa: E501

        :return: The social_profile of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: list[GetCandidatesResponseDataSocialProfile]
        """
        return self._social_profile

    @social_profile.setter
    def social_profile(self, social_profile):
        """Sets the social_profile of this GetCandidatesResponseDataCandidates.

        List of social profiles of the candidate.  # noqa: E501

        :param social_profile: The social_profile of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: list[GetCandidatesResponseDataSocialProfile]
        """

        self._social_profile = social_profile

    @property
    def candidate_id(self):
        """Gets the candidate_id of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Unique identifier for the candidate.  # noqa: E501

        :return: The candidate_id of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._candidate_id

    @candidate_id.setter
    def candidate_id(self, candidate_id):
        """Sets the candidate_id of this GetCandidatesResponseDataCandidates.

        Unique identifier for the candidate.  # noqa: E501

        :param candidate_id: The candidate_id of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: str
        """

        self._candidate_id = candidate_id

    @property
    def interviews_completed_count(self):
        """Gets the interviews_completed_count of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Number of interviews completed with the candidate with respect to this job.  # noqa: E501

        :return: The interviews_completed_count of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: float
        """
        return self._interviews_completed_count

    @interviews_completed_count.setter
    def interviews_completed_count(self, interviews_completed_count):
        """Sets the interviews_completed_count of this GetCandidatesResponseDataCandidates.

        Number of interviews completed with the candidate with respect to this job.  # noqa: E501

        :param interviews_completed_count: The interviews_completed_count of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: float
        """

        self._interviews_completed_count = interviews_completed_count

    @property
    def on_demand_interview_screening(self):
        """Gets the on_demand_interview_screening of this GetCandidatesResponseDataCandidates.  # noqa: E501


        :return: The on_demand_interview_screening of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: GetCandidatesResponseDataOnDemandInterviewScreening
        """
        return self._on_demand_interview_screening

    @on_demand_interview_screening.setter
    def on_demand_interview_screening(self, on_demand_interview_screening):
        """Sets the on_demand_interview_screening of this GetCandidatesResponseDataCandidates.


        :param on_demand_interview_screening: The on_demand_interview_screening of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: GetCandidatesResponseDataOnDemandInterviewScreening
        """

        self._on_demand_interview_screening = on_demand_interview_screening

    @property
    def status(self):
        """Gets the status of this GetCandidatesResponseDataCandidates.  # noqa: E501

        Status of the job.  # noqa: E501

        :return: The status of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this GetCandidatesResponseDataCandidates.

        Status of the job.  # noqa: E501

        :param status: The status of this GetCandidatesResponseDataCandidates.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetCandidatesResponseDataCandidates, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCandidatesResponseDataCandidates):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetAllEvaluationsForInterviewIdDataEvaluations(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'video_screen_id': 'str',
        'user_id': 'str',
        'questionnaire_id': 'str',
        'recruiter_user_id': 'str',
        'overall_evaluation': 'str',
        'overall_evaluation_status': 'str',
        'interview_avg_rating': 'float',
        'interview_overall_avg_rating': 'float',
        'evaluated_date': 'float',
        'answer_ratings': 'list[GetAllEvaluationsForInterviewIdDataAnswerRatings]',
        'recruiter_name': 'str',
        'role_name': 'str',
        'date_created': 'int',
        'last_updated': 'int'
    }

    attribute_map = {
        'video_screen_id': 'videoScreenId',
        'user_id': 'userId',
        'questionnaire_id': 'questionnaireId',
        'recruiter_user_id': 'recruiterUserId',
        'overall_evaluation': 'overallEvaluation',
        'overall_evaluation_status': 'overallEvaluationStatus',
        'interview_avg_rating': 'interviewAvgRating',
        'interview_overall_avg_rating': 'interviewOverallAvgRating',
        'evaluated_date': 'evaluatedDate',
        'answer_ratings': 'answerRatings',
        'recruiter_name': 'recruiterName',
        'role_name': 'roleName',
        'date_created': 'dateCreated',
        'last_updated': 'lastUpdated'
    }

    def __init__(self, video_screen_id=None, user_id=None, questionnaire_id=None, recruiter_user_id=None, overall_evaluation=None, overall_evaluation_status=None, interview_avg_rating=None, interview_overall_avg_rating=None, evaluated_date=None, answer_ratings=None, recruiter_name=None, role_name=None, date_created=None, last_updated=None):  # noqa: E501
        """GetAllEvaluationsForInterviewIdDataEvaluations - a model defined in Swagger"""  # noqa: E501
        self._video_screen_id = None
        self._user_id = None
        self._questionnaire_id = None
        self._recruiter_user_id = None
        self._overall_evaluation = None
        self._overall_evaluation_status = None
        self._interview_avg_rating = None
        self._interview_overall_avg_rating = None
        self._evaluated_date = None
        self._answer_ratings = None
        self._recruiter_name = None
        self._role_name = None
        self._date_created = None
        self._last_updated = None
        self.discriminator = None
        self.video_screen_id = video_screen_id
        self.user_id = user_id
        self.questionnaire_id = questionnaire_id
        self.recruiter_user_id = recruiter_user_id
        self.overall_evaluation = overall_evaluation
        self.overall_evaluation_status = overall_evaluation_status
        self.interview_avg_rating = interview_avg_rating
        self.interview_overall_avg_rating = interview_overall_avg_rating
        self.evaluated_date = evaluated_date
        self.answer_ratings = answer_ratings
        self.recruiter_name = recruiter_name
        self.role_name = role_name
        self.date_created = date_created
        self.last_updated = last_updated

    @property
    def video_screen_id(self):
        """Gets the video_screen_id of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501

        This is the interview id of the interview invited.  # noqa: E501

        :return: The video_screen_id of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._video_screen_id

    @video_screen_id.setter
    def video_screen_id(self, video_screen_id):
        """Sets the video_screen_id of this GetAllEvaluationsForInterviewIdDataEvaluations.

        This is the interview id of the interview invited.  # noqa: E501

        :param video_screen_id: The video_screen_id of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :type: str
        """
        if video_screen_id is None:
            raise ValueError("Invalid value for `video_screen_id`, must not be `None`")  # noqa: E501

        self._video_screen_id = video_screen_id

    @property
    def user_id(self):
        """Gets the user_id of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501

        This is the candidate id of whose interview evaluated.  # noqa: E501

        :return: The user_id of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this GetAllEvaluationsForInterviewIdDataEvaluations.

        This is the candidate id of whose interview evaluated.  # noqa: E501

        :param user_id: The user_id of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :type: str
        """
        if user_id is None:
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def questionnaire_id(self):
        """Gets the questionnaire_id of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501

        This is the questionnaire id.  # noqa: E501

        :return: The questionnaire_id of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._questionnaire_id

    @questionnaire_id.setter
    def questionnaire_id(self, questionnaire_id):
        """Sets the questionnaire_id of this GetAllEvaluationsForInterviewIdDataEvaluations.

        This is the questionnaire id.  # noqa: E501

        :param questionnaire_id: The questionnaire_id of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :type: str
        """
        if questionnaire_id is None:
            raise ValueError("Invalid value for `questionnaire_id`, must not be `None`")  # noqa: E501

        self._questionnaire_id = questionnaire_id

    @property
    def recruiter_user_id(self):
        """Gets the recruiter_user_id of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501

        This is the recruiter user id who has evaluated.  # noqa: E501

        :return: The recruiter_user_id of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_user_id

    @recruiter_user_id.setter
    def recruiter_user_id(self, recruiter_user_id):
        """Sets the recruiter_user_id of this GetAllEvaluationsForInterviewIdDataEvaluations.

        This is the recruiter user id who has evaluated.  # noqa: E501

        :param recruiter_user_id: The recruiter_user_id of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :type: str
        """
        if recruiter_user_id is None:
            raise ValueError("Invalid value for `recruiter_user_id`, must not be `None`")  # noqa: E501

        self._recruiter_user_id = recruiter_user_id

    @property
    def overall_evaluation(self):
        """Gets the overall_evaluation of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501

        This is the comment given by evaluator.  # noqa: E501

        :return: The overall_evaluation of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._overall_evaluation

    @overall_evaluation.setter
    def overall_evaluation(self, overall_evaluation):
        """Sets the overall_evaluation of this GetAllEvaluationsForInterviewIdDataEvaluations.

        This is the comment given by evaluator.  # noqa: E501

        :param overall_evaluation: The overall_evaluation of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :type: str
        """
        if overall_evaluation is None:
            raise ValueError("Invalid value for `overall_evaluation`, must not be `None`")  # noqa: E501

        self._overall_evaluation = overall_evaluation

    @property
    def overall_evaluation_status(self):
        """Gets the overall_evaluation_status of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501

        This can be Yes, No, Maybe. This is the conclusion of the overall evaluation, indicates to consider the candidate or not.  # noqa: E501

        :return: The overall_evaluation_status of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._overall_evaluation_status

    @overall_evaluation_status.setter
    def overall_evaluation_status(self, overall_evaluation_status):
        """Sets the overall_evaluation_status of this GetAllEvaluationsForInterviewIdDataEvaluations.

        This can be Yes, No, Maybe. This is the conclusion of the overall evaluation, indicates to consider the candidate or not.  # noqa: E501

        :param overall_evaluation_status: The overall_evaluation_status of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :type: str
        """
        if overall_evaluation_status is None:
            raise ValueError("Invalid value for `overall_evaluation_status`, must not be `None`")  # noqa: E501

        self._overall_evaluation_status = overall_evaluation_status

    @property
    def interview_avg_rating(self):
        """Gets the interview_avg_rating of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501

        This is the average rating of the interview.  # noqa: E501

        :return: The interview_avg_rating of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :rtype: float
        """
        return self._interview_avg_rating

    @interview_avg_rating.setter
    def interview_avg_rating(self, interview_avg_rating):
        """Sets the interview_avg_rating of this GetAllEvaluationsForInterviewIdDataEvaluations.

        This is the average rating of the interview.  # noqa: E501

        :param interview_avg_rating: The interview_avg_rating of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :type: float
        """
        if interview_avg_rating is None:
            raise ValueError("Invalid value for `interview_avg_rating`, must not be `None`")  # noqa: E501

        self._interview_avg_rating = interview_avg_rating

    @property
    def interview_overall_avg_rating(self):
        """Gets the interview_overall_avg_rating of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501

        This is the overall avg rating among rating given by all recruiters.  # noqa: E501

        :return: The interview_overall_avg_rating of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :rtype: float
        """
        return self._interview_overall_avg_rating

    @interview_overall_avg_rating.setter
    def interview_overall_avg_rating(self, interview_overall_avg_rating):
        """Sets the interview_overall_avg_rating of this GetAllEvaluationsForInterviewIdDataEvaluations.

        This is the overall avg rating among rating given by all recruiters.  # noqa: E501

        :param interview_overall_avg_rating: The interview_overall_avg_rating of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :type: float
        """
        if interview_overall_avg_rating is None:
            raise ValueError("Invalid value for `interview_overall_avg_rating`, must not be `None`")  # noqa: E501

        self._interview_overall_avg_rating = interview_overall_avg_rating

    @property
    def evaluated_date(self):
        """Gets the evaluated_date of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501

        Time stamp of when the interview is evaluated.  # noqa: E501

        :return: The evaluated_date of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :rtype: float
        """
        return self._evaluated_date

    @evaluated_date.setter
    def evaluated_date(self, evaluated_date):
        """Sets the evaluated_date of this GetAllEvaluationsForInterviewIdDataEvaluations.

        Time stamp of when the interview is evaluated.  # noqa: E501

        :param evaluated_date: The evaluated_date of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :type: float
        """
        if evaluated_date is None:
            raise ValueError("Invalid value for `evaluated_date`, must not be `None`")  # noqa: E501

        self._evaluated_date = evaluated_date

    @property
    def answer_ratings(self):
        """Gets the answer_ratings of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501

        Rating for each question.  # noqa: E501

        :return: The answer_ratings of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :rtype: list[GetAllEvaluationsForInterviewIdDataAnswerRatings]
        """
        return self._answer_ratings

    @answer_ratings.setter
    def answer_ratings(self, answer_ratings):
        """Sets the answer_ratings of this GetAllEvaluationsForInterviewIdDataEvaluations.

        Rating for each question.  # noqa: E501

        :param answer_ratings: The answer_ratings of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :type: list[GetAllEvaluationsForInterviewIdDataAnswerRatings]
        """
        if answer_ratings is None:
            raise ValueError("Invalid value for `answer_ratings`, must not be `None`")  # noqa: E501

        self._answer_ratings = answer_ratings

    @property
    def recruiter_name(self):
        """Gets the recruiter_name of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501

        Name of the recruiter.  # noqa: E501

        :return: The recruiter_name of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_name

    @recruiter_name.setter
    def recruiter_name(self, recruiter_name):
        """Sets the recruiter_name of this GetAllEvaluationsForInterviewIdDataEvaluations.

        Name of the recruiter.  # noqa: E501

        :param recruiter_name: The recruiter_name of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :type: str
        """
        if recruiter_name is None:
            raise ValueError("Invalid value for `recruiter_name`, must not be `None`")  # noqa: E501

        self._recruiter_name = recruiter_name

    @property
    def role_name(self):
        """Gets the role_name of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501

        Role assigned for the invitor. Invitor can be recruiter, interviewer, hiring manager etc.  # noqa: E501

        :return: The role_name of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this GetAllEvaluationsForInterviewIdDataEvaluations.

        Role assigned for the invitor. Invitor can be recruiter, interviewer, hiring manager etc.  # noqa: E501

        :param role_name: The role_name of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :type: str
        """
        if role_name is None:
            raise ValueError("Invalid value for `role_name`, must not be `None`")  # noqa: E501

        self._role_name = role_name

    @property
    def date_created(self):
        """Gets the date_created of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501

        Date when the interview is evaluated.  # noqa: E501

        :return: The date_created of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :rtype: int
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this GetAllEvaluationsForInterviewIdDataEvaluations.

        Date when the interview is evaluated.  # noqa: E501

        :param date_created: The date_created of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :type: int
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def last_updated(self):
        """Gets the last_updated of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501

        Date when the evaluation is updated.  # noqa: E501

        :return: The last_updated of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :rtype: int
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this GetAllEvaluationsForInterviewIdDataEvaluations.

        Date when the evaluation is updated.  # noqa: E501

        :param last_updated: The last_updated of this GetAllEvaluationsForInterviewIdDataEvaluations.  # noqa: E501
        :type: int
        """
        if last_updated is None:
            raise ValueError("Invalid value for `last_updated`, must not be `None`")  # noqa: E501

        self._last_updated = last_updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetAllEvaluationsForInterviewIdDataEvaluations, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAllEvaluationsForInterviewIdDataEvaluations):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    candidates-api-activities

    The Note APIs allows you to Add, Get, Update and Delete Notes.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.candidatesapiactivities.candidate_activities_api import CandidateActivitiesApi
from phenom.api.candidatesapiactivities.candidate_notes_api import CandidateNotesApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.candidatesapiactivities.models.add_notes import AddNotes
from phenom.api.candidatesapiactivities.models.bad_request import BadRequest
from phenom.api.candidatesapiactivities.models.bad_request_error import BadRequestError
from phenom.api.candidatesapiactivities.models.bad_request_error_errors import BadRequestErrorErrors
from phenom.api.candidatesapiactivities.models.create_note_success import CreateNoteSuccess
from phenom.api.candidatesapiactivities.models.delete_note_success import DeleteNoteSuccess
from phenom.api.candidatesapiactivities.models.error import Error
from phenom.api.candidatesapiactivities.models.fetch_candidate_notes import FetchCandidateNotes
from phenom.api.candidatesapiactivities.models.fetch_candidate_notes_data import FetchCandidateNotesData
from phenom.api.candidatesapiactivities.models.fetch_candidate_notes_pagination import FetchCandidateNotesPagination
from phenom.api.candidatesapiactivities.models.forbidden_error import ForbiddenError
from phenom.api.candidatesapiactivities.models.get_candidate_job_notes import GetCandidateJobNotes
from phenom.api.candidatesapiactivities.models.get_candidate_job_notes_data import GetCandidateJobNotesData
from phenom.api.candidatesapiactivities.models.get_note_activities import GetNoteActivities
from phenom.api.candidatesapiactivities.models.get_note_activities_data import GetNoteActivitiesData
from phenom.api.candidatesapiactivities.models.get_note_activities_pagination import GetNoteActivitiesPagination
from phenom.api.candidatesapiactivities.models.get_note_activities_scope_attr import GetNoteActivitiesScopeAttr
from phenom.api.candidatesapiactivities.models.internal_server_error import InternalServerError
from phenom.api.candidatesapiactivities.models.internal_server_error_response import InternalServerErrorResponse
from phenom.api.candidatesapiactivities.models.no_content_response import NoContentResponse
from phenom.api.candidatesapiactivities.models.not_found_error import NotFoundError
from phenom.api.candidatesapiactivities.models.profile_action_activities import ProfileActionActivities
from phenom.api.candidatesapiactivities.models.profile_action_activities_data import ProfileActionActivitiesData
from phenom.api.candidatesapiactivities.models.profile_action_activities_pagination import ProfileActionActivitiesPagination
from phenom.api.candidatesapiactivities.models.profile_update_activities import ProfileUpdateActivities
from phenom.api.candidatesapiactivities.models.profile_update_activities_data import ProfileUpdateActivitiesData
from phenom.api.candidatesapiactivities.models.profile_update_activities_pagination import ProfileUpdateActivitiesPagination
from phenom.api.candidatesapiactivities.models.success_response import SuccessResponse
from phenom.api.candidatesapiactivities.models.unauthorized_request import UnauthorizedRequest
from phenom.api.candidatesapiactivities.models.update_candidate_note import UpdateCandidateNote



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class Job(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_id': 'str',
        'applicant_source': 'str'
    }

    attribute_map = {
        'job_id': 'jobId',
        'applicant_source': 'applicantSource'
    }

    def __init__(self, job_id=None, applicant_source=None):  # noqa: E501
        """Job - a model defined in Swagger"""  # noqa: E501
        self._job_id = None
        self._applicant_source = None
        self.discriminator = None
        self.job_id = job_id
        self.applicant_source = applicant_source

    @property
    def job_id(self):
        """Gets the job_id of this Job.  # noqa: E501

        Job Id of the job for which the applicant is applying.  # noqa: E501

        :return: The job_id of this Job.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this Job.

        Job Id of the job for which the applicant is applying.  # noqa: E501

        :param job_id: The job_id of this Job.  # noqa: E501
        :type: str
        """
        if job_id is None:
            raise ValueError("Invalid value for `job_id`, must not be `None`")  # noqa: E501

        self._job_id = job_id

    @property
    def applicant_source(self):
        """Gets the applicant_source of this Job.  # noqa: E501

        Source of the Application. Eg: LinkedIn, Indeed, Naukri, Resume Upload etc.  # noqa: E501

        :return: The applicant_source of this Job.  # noqa: E501
        :rtype: str
        """
        return self._applicant_source

    @applicant_source.setter
    def applicant_source(self, applicant_source):
        """Sets the applicant_source of this Job.

        Source of the Application. Eg: LinkedIn, Indeed, Naukri, Resume Upload etc.  # noqa: E501

        :param applicant_source: The applicant_source of this Job.  # noqa: E501
        :type: str
        """
        if applicant_source is None:
            raise ValueError("Invalid value for `applicant_source`, must not be `None`")  # noqa: E501

        self._applicant_source = applicant_source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Job, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Job):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import http.client
import datetime
import jwt

token_details = {"token": "", "expiry": ""}


def tokengeneration(url, client_id, client_secret):
    try:
        conn = http.client.HTTPSConnection(url)
        payload = "clientId=" + client_id + "&" "clientSecret=" + client_secret
        headers = {
            'AUTH_COOKIE': '1634546337.139.324.65458',
            'Content-Type': 'application/x-www-form-urlencoded',
            'Cookie': 'AUTH_COOKIE=1663132096.438.8422.634494|09d85645d3393accb9766216f4aa3fc4; LOGIN_COOKIE=1674571736.129.29.465911|6215ab38db341c1677dfbe9882af3be1'
        }
        conn.request("POST", "/token", payload, headers)
        res = conn.getresponse()
        data = res.read()
        data = data.decode("utf-8")
        i = data.index(":")
        j = data.index(",")
        conn.close()
        return "Bearer " + data[i + 2:j - 1]
    except:
        raise Exception("provide valid credentials")


# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CreateProjectRequestCategoryList(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_category_id': 'str',
        'category': 'str'
    }

    attribute_map = {
        'internal_category_id': 'internalCategoryId',
        'category': 'category'
    }

    def __init__(self, internal_category_id=None, category=None):  # noqa: E501
        """CreateProjectRequestCategoryList - a model defined in Swagger"""  # noqa: E501
        self._internal_category_id = None
        self._category = None
        self.discriminator = None
        self.internal_category_id = internal_category_id
        self.category = category

    @property
    def internal_category_id(self):
        """Gets the internal_category_id of this CreateProjectRequestCategoryList.  # noqa: E501

        Internal category ID.  # noqa: E501

        :return: The internal_category_id of this CreateProjectRequestCategoryList.  # noqa: E501
        :rtype: str
        """
        return self._internal_category_id

    @internal_category_id.setter
    def internal_category_id(self, internal_category_id):
        """Sets the internal_category_id of this CreateProjectRequestCategoryList.

        Internal category ID.  # noqa: E501

        :param internal_category_id: The internal_category_id of this CreateProjectRequestCategoryList.  # noqa: E501
        :type: str
        """
        if internal_category_id is None:
            raise ValueError("Invalid value for `internal_category_id`, must not be `None`")  # noqa: E501

        self._internal_category_id = internal_category_id

    @property
    def category(self):
        """Gets the category of this CreateProjectRequestCategoryList.  # noqa: E501

        Category name.  # noqa: E501

        :return: The category of this CreateProjectRequestCategoryList.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this CreateProjectRequestCategoryList.

        Category name.  # noqa: E501

        :param category: The category of this CreateProjectRequestCategoryList.  # noqa: E501
        :type: str
        """
        if category is None:
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501

        self._category = category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateProjectRequestCategoryList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateProjectRequestCategoryList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.candidatesapiactivities.candidate_notes_api import CandidateNotesApi
from phenom.api.candidatesapiactivities.candidate_activities_api import CandidateActivitiesApi
from phenom.api.candidatesAttachmentsApi.candidate_attachments_api import CandidateAttachmentsApi
from phenom.api.candidates.candidates_api import CandidatesApi
class Candidate(object):
    def __init__(self, token, gateway_url, apikey=None):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey

    def candidate_notes_api(self):
        return CandidateNotesApi(self.__token, self.__gateway_url, self.__apikey)

    def candidate_activities_api(self):
        return CandidateActivitiesApi(self.__token, self.__gateway_url, self.__apikey)

    def candidate_attachments_api(self):
        return CandidateAttachmentsApi(self.__token, self.__gateway_url, self.__apikey)

    def candidates_api(self):
        return CandidatesApi(self.__token, self.__gateway_url, self.__apikey)


# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class HiringStatusUpdateRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'previous_hiring_status': 'str',
        'previous_step': 'str',
        'hiring_status': 'str',
        'hiring_step': 'str',
        'is_rejected': 'bool',
        'rejection_reason': 'str',
        'rejection_reason_id': 'str',
        'reject_code': 'str',
        'workflow_step_id': 'str',
        'hiring_status_update_date': 'str',
        'current_status_code': 'str',
        'current_step_code': 'str',
        'destination_status_code': 'str',
        'two_way_request': 'bool',
        'recruiter_name': 'str',
        'recruiter_email': 'str',
        'recruiter_user_id': 'str'
    }

    attribute_map = {
        'previous_hiring_status': 'previousHiringStatus',
        'previous_step': 'previousStep',
        'hiring_status': 'hiringStatus',
        'hiring_step': 'hiringStep',
        'is_rejected': 'isRejected',
        'rejection_reason': 'rejectionReason',
        'rejection_reason_id': 'rejectionReasonId',
        'reject_code': 'rejectCode',
        'workflow_step_id': 'workflowStepId',
        'hiring_status_update_date': 'hiringStatusUpdateDate',
        'current_status_code': 'currentStatusCode',
        'current_step_code': 'currentStepCode',
        'destination_status_code': 'destinationStatusCode',
        'two_way_request': 'twoWayRequest',
        'recruiter_name': 'recruiterName',
        'recruiter_email': 'recruiterEmail',
        'recruiter_user_id': 'recruiterUserId'
    }

    def __init__(self, previous_hiring_status=None, previous_step=None, hiring_status=None, hiring_step=None, is_rejected=None, rejection_reason=None, rejection_reason_id=None, reject_code=None, workflow_step_id=None, hiring_status_update_date=None, current_status_code=None, current_step_code=None, destination_status_code=None, two_way_request=None, recruiter_name=None, recruiter_email=None, recruiter_user_id=None):  # noqa: E501
        """HiringStatusUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._previous_hiring_status = None
        self._previous_step = None
        self._hiring_status = None
        self._hiring_step = None
        self._is_rejected = None
        self._rejection_reason = None
        self._rejection_reason_id = None
        self._reject_code = None
        self._workflow_step_id = None
        self._hiring_status_update_date = None
        self._current_status_code = None
        self._current_step_code = None
        self._destination_status_code = None
        self._two_way_request = None
        self._recruiter_name = None
        self._recruiter_email = None
        self._recruiter_user_id = None
        self.discriminator = None
        if previous_hiring_status is not None:
            self.previous_hiring_status = previous_hiring_status
        if previous_step is not None:
            self.previous_step = previous_step
        if hiring_status is not None:
            self.hiring_status = hiring_status
        if hiring_step is not None:
            self.hiring_step = hiring_step
        if is_rejected is not None:
            self.is_rejected = is_rejected
        if rejection_reason is not None:
            self.rejection_reason = rejection_reason
        if rejection_reason_id is not None:
            self.rejection_reason_id = rejection_reason_id
        if reject_code is not None:
            self.reject_code = reject_code
        if workflow_step_id is not None:
            self.workflow_step_id = workflow_step_id
        if hiring_status_update_date is not None:
            self.hiring_status_update_date = hiring_status_update_date
        if current_status_code is not None:
            self.current_status_code = current_status_code
        if current_step_code is not None:
            self.current_step_code = current_step_code
        if destination_status_code is not None:
            self.destination_status_code = destination_status_code
        if two_way_request is not None:
            self.two_way_request = two_way_request
        if recruiter_name is not None:
            self.recruiter_name = recruiter_name
        if recruiter_email is not None:
            self.recruiter_email = recruiter_email
        if recruiter_user_id is not None:
            self.recruiter_user_id = recruiter_user_id

    @property
    def previous_hiring_status(self):
        """Gets the previous_hiring_status of this HiringStatusUpdateRequest.  # noqa: E501

        The previous hiring status of the candidate.  # noqa: E501

        :return: The previous_hiring_status of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._previous_hiring_status

    @previous_hiring_status.setter
    def previous_hiring_status(self, previous_hiring_status):
        """Sets the previous_hiring_status of this HiringStatusUpdateRequest.

        The previous hiring status of the candidate.  # noqa: E501

        :param previous_hiring_status: The previous_hiring_status of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._previous_hiring_status = previous_hiring_status

    @property
    def previous_step(self):
        """Gets the previous_step of this HiringStatusUpdateRequest.  # noqa: E501

        The previous step in the hiring process.  # noqa: E501

        :return: The previous_step of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._previous_step

    @previous_step.setter
    def previous_step(self, previous_step):
        """Sets the previous_step of this HiringStatusUpdateRequest.

        The previous step in the hiring process.  # noqa: E501

        :param previous_step: The previous_step of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._previous_step = previous_step

    @property
    def hiring_status(self):
        """Gets the hiring_status of this HiringStatusUpdateRequest.  # noqa: E501

        The current hiring status of the candidate.  # noqa: E501

        :return: The hiring_status of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._hiring_status

    @hiring_status.setter
    def hiring_status(self, hiring_status):
        """Sets the hiring_status of this HiringStatusUpdateRequest.

        The current hiring status of the candidate.  # noqa: E501

        :param hiring_status: The hiring_status of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._hiring_status = hiring_status

    @property
    def hiring_step(self):
        """Gets the hiring_step of this HiringStatusUpdateRequest.  # noqa: E501

        The current step in the hiring process.  # noqa: E501

        :return: The hiring_step of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._hiring_step

    @hiring_step.setter
    def hiring_step(self, hiring_step):
        """Sets the hiring_step of this HiringStatusUpdateRequest.

        The current step in the hiring process.  # noqa: E501

        :param hiring_step: The hiring_step of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._hiring_step = hiring_step

    @property
    def is_rejected(self):
        """Gets the is_rejected of this HiringStatusUpdateRequest.  # noqa: E501

        A boolean indicating whether the candidate has been rejected.  # noqa: E501

        :return: The is_rejected of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_rejected

    @is_rejected.setter
    def is_rejected(self, is_rejected):
        """Sets the is_rejected of this HiringStatusUpdateRequest.

        A boolean indicating whether the candidate has been rejected.  # noqa: E501

        :param is_rejected: The is_rejected of this HiringStatusUpdateRequest.  # noqa: E501
        :type: bool
        """

        self._is_rejected = is_rejected

    @property
    def rejection_reason(self):
        """Gets the rejection_reason of this HiringStatusUpdateRequest.  # noqa: E501

        The reason for candidate rejection.  # noqa: E501

        :return: The rejection_reason of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._rejection_reason

    @rejection_reason.setter
    def rejection_reason(self, rejection_reason):
        """Sets the rejection_reason of this HiringStatusUpdateRequest.

        The reason for candidate rejection.  # noqa: E501

        :param rejection_reason: The rejection_reason of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._rejection_reason = rejection_reason

    @property
    def rejection_reason_id(self):
        """Gets the rejection_reason_id of this HiringStatusUpdateRequest.  # noqa: E501

        The unique identifier for the rejection reason.  # noqa: E501

        :return: The rejection_reason_id of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._rejection_reason_id

    @rejection_reason_id.setter
    def rejection_reason_id(self, rejection_reason_id):
        """Sets the rejection_reason_id of this HiringStatusUpdateRequest.

        The unique identifier for the rejection reason.  # noqa: E501

        :param rejection_reason_id: The rejection_reason_id of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._rejection_reason_id = rejection_reason_id

    @property
    def reject_code(self):
        """Gets the reject_code of this HiringStatusUpdateRequest.  # noqa: E501

        The rejection code associated with the rejection.  # noqa: E501

        :return: The reject_code of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._reject_code

    @reject_code.setter
    def reject_code(self, reject_code):
        """Sets the reject_code of this HiringStatusUpdateRequest.

        The rejection code associated with the rejection.  # noqa: E501

        :param reject_code: The reject_code of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._reject_code = reject_code

    @property
    def workflow_step_id(self):
        """Gets the workflow_step_id of this HiringStatusUpdateRequest.  # noqa: E501

        The unique identifier for the current workflow step.  # noqa: E501

        :return: The workflow_step_id of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._workflow_step_id

    @workflow_step_id.setter
    def workflow_step_id(self, workflow_step_id):
        """Sets the workflow_step_id of this HiringStatusUpdateRequest.

        The unique identifier for the current workflow step.  # noqa: E501

        :param workflow_step_id: The workflow_step_id of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._workflow_step_id = workflow_step_id

    @property
    def hiring_status_update_date(self):
        """Gets the hiring_status_update_date of this HiringStatusUpdateRequest.  # noqa: E501

        The date when the hiring status was last updated.  # noqa: E501

        :return: The hiring_status_update_date of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._hiring_status_update_date

    @hiring_status_update_date.setter
    def hiring_status_update_date(self, hiring_status_update_date):
        """Sets the hiring_status_update_date of this HiringStatusUpdateRequest.

        The date when the hiring status was last updated.  # noqa: E501

        :param hiring_status_update_date: The hiring_status_update_date of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._hiring_status_update_date = hiring_status_update_date

    @property
    def current_status_code(self):
        """Gets the current_status_code of this HiringStatusUpdateRequest.  # noqa: E501

        The current status code of the hiring process.  # noqa: E501

        :return: The current_status_code of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._current_status_code

    @current_status_code.setter
    def current_status_code(self, current_status_code):
        """Sets the current_status_code of this HiringStatusUpdateRequest.

        The current status code of the hiring process.  # noqa: E501

        :param current_status_code: The current_status_code of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._current_status_code = current_status_code

    @property
    def current_step_code(self):
        """Gets the current_step_code of this HiringStatusUpdateRequest.  # noqa: E501

        The current step code of the hiring process.  # noqa: E501

        :return: The current_step_code of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._current_step_code

    @current_step_code.setter
    def current_step_code(self, current_step_code):
        """Sets the current_step_code of this HiringStatusUpdateRequest.

        The current step code of the hiring process.  # noqa: E501

        :param current_step_code: The current_step_code of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._current_step_code = current_step_code

    @property
    def destination_status_code(self):
        """Gets the destination_status_code of this HiringStatusUpdateRequest.  # noqa: E501

        The destination status code for the next step in the hiring process.  # noqa: E501

        :return: The destination_status_code of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._destination_status_code

    @destination_status_code.setter
    def destination_status_code(self, destination_status_code):
        """Sets the destination_status_code of this HiringStatusUpdateRequest.

        The destination status code for the next step in the hiring process.  # noqa: E501

        :param destination_status_code: The destination_status_code of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._destination_status_code = destination_status_code

    @property
    def two_way_request(self):
        """Gets the two_way_request of this HiringStatusUpdateRequest.  # noqa: E501

        A boolean indicating whether the hiring status update is a two-way request.  # noqa: E501

        :return: The two_way_request of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._two_way_request

    @two_way_request.setter
    def two_way_request(self, two_way_request):
        """Sets the two_way_request of this HiringStatusUpdateRequest.

        A boolean indicating whether the hiring status update is a two-way request.  # noqa: E501

        :param two_way_request: The two_way_request of this HiringStatusUpdateRequest.  # noqa: E501
        :type: bool
        """

        self._two_way_request = two_way_request

    @property
    def recruiter_name(self):
        """Gets the recruiter_name of this HiringStatusUpdateRequest.  # noqa: E501

        The name of the recruiter making the hiring status update.  # noqa: E501

        :return: The recruiter_name of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_name

    @recruiter_name.setter
    def recruiter_name(self, recruiter_name):
        """Sets the recruiter_name of this HiringStatusUpdateRequest.

        The name of the recruiter making the hiring status update.  # noqa: E501

        :param recruiter_name: The recruiter_name of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._recruiter_name = recruiter_name

    @property
    def recruiter_email(self):
        """Gets the recruiter_email of this HiringStatusUpdateRequest.  # noqa: E501

        The email address of the recruiter making the hiring status update.  # noqa: E501

        :return: The recruiter_email of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_email

    @recruiter_email.setter
    def recruiter_email(self, recruiter_email):
        """Sets the recruiter_email of this HiringStatusUpdateRequest.

        The email address of the recruiter making the hiring status update.  # noqa: E501

        :param recruiter_email: The recruiter_email of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._recruiter_email = recruiter_email

    @property
    def recruiter_user_id(self):
        """Gets the recruiter_user_id of this HiringStatusUpdateRequest.  # noqa: E501

        The unique identifier for the recruiter making the hiring status update.  # noqa: E501

        :return: The recruiter_user_id of this HiringStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_user_id

    @recruiter_user_id.setter
    def recruiter_user_id(self, recruiter_user_id):
        """Sets the recruiter_user_id of this HiringStatusUpdateRequest.

        The unique identifier for the recruiter making the hiring status update.  # noqa: E501

        :param recruiter_user_id: The recruiter_user_id of this HiringStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._recruiter_user_id = recruiter_user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HiringStatusUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HiringStatusUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    servicehub-public-api

    Public APIs for managing user data.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.servicehubpublic.models.error_response import ErrorResponse
from phenom.api.servicehubpublic.models.search_request import SearchRequest
from phenom.api.servicehubpublic.models.search_request_date_filter import SearchRequestDateFilter
from phenom.api.servicehubpublic.models.search_request_product import SearchRequestProduct
from phenom.api.servicehubpublic.models.search_response import SearchResponse
from phenom.api.servicehubpublic.models.search_response_data import SearchResponseData
from phenom.api.servicehubpublic.models.unauthorized_response import UnauthorizedResponse



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class AddressData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address_line1': 'str',
        'address_line2': 'str',
        'region': 'str',
        'city': 'str',
        'country': 'str'
    }

    attribute_map = {
        'address_line1': 'addressLine1',
        'address_line2': 'addressLine2',
        'region': 'region',
        'city': 'city',
        'country': 'country'
    }

    def __init__(self, address_line1=None, address_line2=None, region=None, city=None, country=None):  # noqa: E501
        """AddressData - a model defined in Swagger"""  # noqa: E501
        self._address_line1 = None
        self._address_line2 = None
        self._region = None
        self._city = None
        self._country = None
        self.discriminator = None
        self.address_line1 = address_line1
        if address_line2 is not None:
            self.address_line2 = address_line2
        if region is not None:
            self.region = region
        if city is not None:
            self.city = city
        if country is not None:
            self.country = country

    @property
    def address_line1(self):
        """Gets the address_line1 of this AddressData.  # noqa: E501

        Address Line 1.  # noqa: E501

        :return: The address_line1 of this AddressData.  # noqa: E501
        :rtype: str
        """
        return self._address_line1

    @address_line1.setter
    def address_line1(self, address_line1):
        """Sets the address_line1 of this AddressData.

        Address Line 1.  # noqa: E501

        :param address_line1: The address_line1 of this AddressData.  # noqa: E501
        :type: str
        """
        if address_line1 is None:
            raise ValueError("Invalid value for `address_line1`, must not be `None`")  # noqa: E501

        self._address_line1 = address_line1

    @property
    def address_line2(self):
        """Gets the address_line2 of this AddressData.  # noqa: E501

        Address Line 2.  # noqa: E501

        :return: The address_line2 of this AddressData.  # noqa: E501
        :rtype: str
        """
        return self._address_line2

    @address_line2.setter
    def address_line2(self, address_line2):
        """Sets the address_line2 of this AddressData.

        Address Line 2.  # noqa: E501

        :param address_line2: The address_line2 of this AddressData.  # noqa: E501
        :type: str
        """

        self._address_line2 = address_line2

    @property
    def region(self):
        """Gets the region of this AddressData.  # noqa: E501

        Region/County/State of the address.  # noqa: E501

        :return: The region of this AddressData.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this AddressData.

        Region/County/State of the address.  # noqa: E501

        :param region: The region of this AddressData.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def city(self):
        """Gets the city of this AddressData.  # noqa: E501

        City of the address.  # noqa: E501

        :return: The city of this AddressData.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this AddressData.

        City of the address.  # noqa: E501

        :param city: The city of this AddressData.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def country(self):
        """Gets the country of this AddressData.  # noqa: E501

        Country of the address.  # noqa: E501

        :return: The country of this AddressData.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this AddressData.

        Country of the address.  # noqa: E501

        :param country: The country of this AddressData.  # noqa: E501
        :type: str
        """

        self._country = country

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddressData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddressData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ApplicationWithId(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'candidate_data': 'CandidateWithId',
        'job_application_data': 'Job',
        'custom_field_data': 'object',
        'id': 'str'
    }

    attribute_map = {
        'candidate_data': 'candidateData',
        'job_application_data': 'jobApplicationData',
        'custom_field_data': 'customFieldData',
        'id': 'id'
    }

    def __init__(self, candidate_data=None, job_application_data=None, custom_field_data=None, id=None):  # noqa: E501
        """ApplicationWithId - a model defined in Swagger"""  # noqa: E501
        self._candidate_data = None
        self._job_application_data = None
        self._custom_field_data = None
        self._id = None
        self.discriminator = None
        if candidate_data is not None:
            self.candidate_data = candidate_data
        if job_application_data is not None:
            self.job_application_data = job_application_data
        if custom_field_data is not None:
            self.custom_field_data = custom_field_data
        if id is not None:
            self.id = id

    @property
    def candidate_data(self):
        """Gets the candidate_data of this ApplicationWithId.  # noqa: E501


        :return: The candidate_data of this ApplicationWithId.  # noqa: E501
        :rtype: CandidateWithId
        """
        return self._candidate_data

    @candidate_data.setter
    def candidate_data(self, candidate_data):
        """Sets the candidate_data of this ApplicationWithId.


        :param candidate_data: The candidate_data of this ApplicationWithId.  # noqa: E501
        :type: CandidateWithId
        """

        self._candidate_data = candidate_data

    @property
    def job_application_data(self):
        """Gets the job_application_data of this ApplicationWithId.  # noqa: E501


        :return: The job_application_data of this ApplicationWithId.  # noqa: E501
        :rtype: Job
        """
        return self._job_application_data

    @job_application_data.setter
    def job_application_data(self, job_application_data):
        """Sets the job_application_data of this ApplicationWithId.


        :param job_application_data: The job_application_data of this ApplicationWithId.  # noqa: E501
        :type: Job
        """

        self._job_application_data = job_application_data

    @property
    def custom_field_data(self):
        """Gets the custom_field_data of this ApplicationWithId.  # noqa: E501


        :return: The custom_field_data of this ApplicationWithId.  # noqa: E501
        :rtype: object
        """
        return self._custom_field_data

    @custom_field_data.setter
    def custom_field_data(self, custom_field_data):
        """Sets the custom_field_data of this ApplicationWithId.


        :param custom_field_data: The custom_field_data of this ApplicationWithId.  # noqa: E501
        :type: object
        """

        self._custom_field_data = custom_field_data

    @property
    def id(self):
        """Gets the id of this ApplicationWithId.  # noqa: E501

        It is a 24-digit hexadecimal value that represents Application Id.  # noqa: E501

        :return: The id of this ApplicationWithId.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ApplicationWithId.

        It is a 24-digit hexadecimal value that represents Application Id.  # noqa: E501

        :param id: The id of this ApplicationWithId.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApplicationWithId, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationWithId):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    candidates-api

    The Candidate APIs allows you to add, update and delete candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class AwardDataAwards(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'field_id': 'str',
        'description': 'str',
        'title': 'str',
        'awarded_on': 'AwardDataAwardedOn',
        'valid': 'bool'
    }

    attribute_map = {
        'field_id': 'fieldID',
        'description': 'description',
        'title': 'title',
        'awarded_on': 'awardedOn',
        'valid': 'valid'
    }

    def __init__(self, field_id=None, description=None, title=None, awarded_on=None, valid=None):  # noqa: E501
        """AwardDataAwards - a model defined in Swagger"""  # noqa: E501
        self._field_id = None
        self._description = None
        self._title = None
        self._awarded_on = None
        self._valid = None
        self.discriminator = None
        if field_id is not None:
            self.field_id = field_id
        if description is not None:
            self.description = description
        if title is not None:
            self.title = title
        if awarded_on is not None:
            self.awarded_on = awarded_on
        if valid is not None:
            self.valid = valid

    @property
    def field_id(self):
        """Gets the field_id of this AwardDataAwards.  # noqa: E501

        Unique identifier for the award field.  # noqa: E501

        :return: The field_id of this AwardDataAwards.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this AwardDataAwards.

        Unique identifier for the award field.  # noqa: E501

        :param field_id: The field_id of this AwardDataAwards.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def description(self):
        """Gets the description of this AwardDataAwards.  # noqa: E501

        Description of the award.  # noqa: E501

        :return: The description of this AwardDataAwards.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AwardDataAwards.

        Description of the award.  # noqa: E501

        :param description: The description of this AwardDataAwards.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def title(self):
        """Gets the title of this AwardDataAwards.  # noqa: E501

        Title of the award.  # noqa: E501

        :return: The title of this AwardDataAwards.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this AwardDataAwards.

        Title of the award.  # noqa: E501

        :param title: The title of this AwardDataAwards.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def awarded_on(self):
        """Gets the awarded_on of this AwardDataAwards.  # noqa: E501


        :return: The awarded_on of this AwardDataAwards.  # noqa: E501
        :rtype: AwardDataAwardedOn
        """
        return self._awarded_on

    @awarded_on.setter
    def awarded_on(self, awarded_on):
        """Sets the awarded_on of this AwardDataAwards.


        :param awarded_on: The awarded_on of this AwardDataAwards.  # noqa: E501
        :type: AwardDataAwardedOn
        """

        self._awarded_on = awarded_on

    @property
    def valid(self):
        """Gets the valid of this AwardDataAwards.  # noqa: E501

        Indicator of the award validity.  # noqa: E501

        :return: The valid of this AwardDataAwards.  # noqa: E501
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """Sets the valid of this AwardDataAwards.

        Indicator of the award validity.  # noqa: E501

        :param valid: The valid of this AwardDataAwards.  # noqa: E501
        :type: bool
        """

        self._valid = valid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AwardDataAwards, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AwardDataAwards):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class TaskDetailsRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_from': 'float',
        'size': 'float',
        'task': 'str',
        'accessrole': 'str'
    }

    attribute_map = {
        '_from': 'from',
        'size': 'size',
        'task': 'task',
        'accessrole': 'accessrole'
    }

    def __init__(self, _from=None, size=None, task=None, accessrole=None):  # noqa: E501
        """TaskDetailsRequest - a model defined in Swagger"""  # noqa: E501
        self.__from = None
        self._size = None
        self._task = None
        self._accessrole = None
        self.discriminator = None
        if _from is not None:
            self._from = _from
        if size is not None:
            self.size = size
        if task is not None:
            self.task = task
        if accessrole is not None:
            self.accessrole = accessrole

    @property
    def _from(self):
        """Gets the _from of this TaskDetailsRequest.  # noqa: E501

        Number to fetch data from.  # noqa: E501

        :return: The _from of this TaskDetailsRequest.  # noqa: E501
        :rtype: float
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this TaskDetailsRequest.

        Number to fetch data from.  # noqa: E501

        :param _from: The _from of this TaskDetailsRequest.  # noqa: E501
        :type: float
        """

        self.__from = _from

    @property
    def size(self):
        """Gets the size of this TaskDetailsRequest.  # noqa: E501

        Number of jobs to fetch.  # noqa: E501

        :return: The size of this TaskDetailsRequest.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this TaskDetailsRequest.

        Number of jobs to fetch.  # noqa: E501

        :param size: The size of this TaskDetailsRequest.  # noqa: E501
        :type: float
        """

        self._size = size

    @property
    def task(self):
        """Gets the task of this TaskDetailsRequest.  # noqa: E501

        Pending task name.  # noqa: E501

        :return: The task of this TaskDetailsRequest.  # noqa: E501
        :rtype: str
        """
        return self._task

    @task.setter
    def task(self, task):
        """Sets the task of this TaskDetailsRequest.

        Pending task name.  # noqa: E501

        :param task: The task of this TaskDetailsRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["REVIEW_PENDING", "EVALUATION_PENDING", "OFFER_PENDING", "OFFER_PROCEED"]  # noqa: E501
        if task not in allowed_values:
            raise ValueError(
                "Invalid value for `task` ({0}), must be one of {1}"  # noqa: E501
                .format(task, allowed_values)
            )

        self._task = task

    @property
    def accessrole(self):
        """Gets the accessrole of this TaskDetailsRequest.  # noqa: E501

        This field is used to get only jobs of a certain role.  # noqa: E501

        :return: The accessrole of this TaskDetailsRequest.  # noqa: E501
        :rtype: str
        """
        return self._accessrole

    @accessrole.setter
    def accessrole(self, accessrole):
        """Sets the accessrole of this TaskDetailsRequest.

        This field is used to get only jobs of a certain role.  # noqa: E501

        :param accessrole: The accessrole of this TaskDetailsRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["HIRING_MANAGER", "INTERVIEWER"]  # noqa: E501
        if accessrole not in allowed_values:
            raise ValueError(
                "Invalid value for `accessrole` ({0}), must be one of {1}"  # noqa: E501
                .format(accessrole, allowed_values)
            )

        self._accessrole = accessrole

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaskDetailsRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskDetailsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    resume-parser-api

    The Resume Parser extracts important information of a candidate such as candidate's name, contact information, email id, education, work experience, and skills, etc. from the resume using Deep learning models.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ResumeResponseDataResumedataEducationhistory(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'school': 'str',
        'city': 'str',
        'state': 'str',
        'country': 'str',
        'degree': 'str',
        'startdate': 'str',
        'enddate': 'str',
        'aggregate': 'str'
    }

    attribute_map = {
        'school': 'school',
        'city': 'city',
        'state': 'state',
        'country': 'country',
        'degree': 'degree',
        'startdate': 'startdate',
        'enddate': 'enddate',
        'aggregate': 'aggregate'
    }

    def __init__(self, school=None, city=None, state=None, country=None, degree=None, startdate=None, enddate=None, aggregate=None):  # noqa: E501
        """ResumeResponseDataResumedataEducationhistory - a model defined in Swagger"""  # noqa: E501
        self._school = None
        self._city = None
        self._state = None
        self._country = None
        self._degree = None
        self._startdate = None
        self._enddate = None
        self._aggregate = None
        self.discriminator = None
        if school is not None:
            self.school = school
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country
        if degree is not None:
            self.degree = degree
        if startdate is not None:
            self.startdate = startdate
        if enddate is not None:
            self.enddate = enddate
        if aggregate is not None:
            self.aggregate = aggregate

    @property
    def school(self):
        """Gets the school of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        College name.  # noqa: E501

        :return: The school of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._school

    @school.setter
    def school(self, school):
        """Sets the school of this ResumeResponseDataResumedataEducationhistory.

        College name.  # noqa: E501

        :param school: The school of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._school = school

    @property
    def city(self):
        """Gets the city of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        City.  # noqa: E501

        :return: The city of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this ResumeResponseDataResumedataEducationhistory.

        City.  # noqa: E501

        :param city: The city of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        state  # noqa: E501

        :return: The state of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ResumeResponseDataResumedataEducationhistory.

        state  # noqa: E501

        :param state: The state of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        Country.  # noqa: E501

        :return: The country of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this ResumeResponseDataResumedataEducationhistory.

        Country.  # noqa: E501

        :param country: The country of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def degree(self):
        """Gets the degree of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        Degree.  # noqa: E501

        :return: The degree of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._degree

    @degree.setter
    def degree(self, degree):
        """Sets the degree of this ResumeResponseDataResumedataEducationhistory.

        Degree.  # noqa: E501

        :param degree: The degree of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._degree = degree

    @property
    def startdate(self):
        """Gets the startdate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        Joining date.  # noqa: E501

        :return: The startdate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._startdate

    @startdate.setter
    def startdate(self, startdate):
        """Sets the startdate of this ResumeResponseDataResumedataEducationhistory.

        Joining date.  # noqa: E501

        :param startdate: The startdate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._startdate = startdate

    @property
    def enddate(self):
        """Gets the enddate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        End date.  # noqa: E501

        :return: The enddate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._enddate

    @enddate.setter
    def enddate(self, enddate):
        """Sets the enddate of this ResumeResponseDataResumedataEducationhistory.

        End date.  # noqa: E501

        :param enddate: The enddate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._enddate = enddate

    @property
    def aggregate(self):
        """Gets the aggregate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        Aggregate values.  # noqa: E501

        :return: The aggregate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._aggregate

    @aggregate.setter
    def aggregate(self, aggregate):
        """Sets the aggregate of this ResumeResponseDataResumedataEducationhistory.

        Aggregate values.  # noqa: E501

        :param aggregate: The aggregate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._aggregate = aggregate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResumeResponseDataResumedataEducationhistory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResumeResponseDataResumedataEducationhistory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class UpdateQuestionnaireRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'lc_questionnaire_name': 'str',
        'questionnaire_name': 'str',
        'question_ids': 'list[str]',
        'questionnaire_details': 'UpdateQuestionnaireRequestQuestionnaireDetails',
        'date_created': 'int',
        'last_updated': 'int',
        'questions': 'list[UpdateQuestionnaireRequestQuestions]',
        'locales': 'list[UpdateQuestionnaireRequestLocales]',
        'recruiter_user_id': 'str'
    }

    attribute_map = {
        'lc_questionnaire_name': 'lcQuestionnaireName',
        'questionnaire_name': 'questionnaireName',
        'question_ids': 'questionIds',
        'questionnaire_details': 'questionnaireDetails',
        'date_created': 'dateCreated',
        'last_updated': 'lastUpdated',
        'questions': 'questions',
        'locales': 'locales',
        'recruiter_user_id': 'recruiterUserId'
    }

    def __init__(self, lc_questionnaire_name=None, questionnaire_name=None, question_ids=None, questionnaire_details=None, date_created=None, last_updated=None, questions=None, locales=None, recruiter_user_id=None):  # noqa: E501
        """UpdateQuestionnaireRequest - a model defined in Swagger"""  # noqa: E501
        self._lc_questionnaire_name = None
        self._questionnaire_name = None
        self._question_ids = None
        self._questionnaire_details = None
        self._date_created = None
        self._last_updated = None
        self._questions = None
        self._locales = None
        self._recruiter_user_id = None
        self.discriminator = None
        self.lc_questionnaire_name = lc_questionnaire_name
        self.questionnaire_name = questionnaire_name
        self.question_ids = question_ids
        self.questionnaire_details = questionnaire_details
        self.date_created = date_created
        self.last_updated = last_updated
        self.questions = questions
        self.locales = locales
        self.recruiter_user_id = recruiter_user_id

    @property
    def lc_questionnaire_name(self):
        """Gets the lc_questionnaire_name of this UpdateQuestionnaireRequest.  # noqa: E501

        Questionnaire name in lower case.  # noqa: E501

        :return: The lc_questionnaire_name of this UpdateQuestionnaireRequest.  # noqa: E501
        :rtype: str
        """
        return self._lc_questionnaire_name

    @lc_questionnaire_name.setter
    def lc_questionnaire_name(self, lc_questionnaire_name):
        """Sets the lc_questionnaire_name of this UpdateQuestionnaireRequest.

        Questionnaire name in lower case.  # noqa: E501

        :param lc_questionnaire_name: The lc_questionnaire_name of this UpdateQuestionnaireRequest.  # noqa: E501
        :type: str
        """
        if lc_questionnaire_name is None:
            raise ValueError("Invalid value for `lc_questionnaire_name`, must not be `None`")  # noqa: E501

        self._lc_questionnaire_name = lc_questionnaire_name

    @property
    def questionnaire_name(self):
        """Gets the questionnaire_name of this UpdateQuestionnaireRequest.  # noqa: E501

        Questionnaire name.  # noqa: E501

        :return: The questionnaire_name of this UpdateQuestionnaireRequest.  # noqa: E501
        :rtype: str
        """
        return self._questionnaire_name

    @questionnaire_name.setter
    def questionnaire_name(self, questionnaire_name):
        """Sets the questionnaire_name of this UpdateQuestionnaireRequest.

        Questionnaire name.  # noqa: E501

        :param questionnaire_name: The questionnaire_name of this UpdateQuestionnaireRequest.  # noqa: E501
        :type: str
        """
        if questionnaire_name is None:
            raise ValueError("Invalid value for `questionnaire_name`, must not be `None`")  # noqa: E501

        self._questionnaire_name = questionnaire_name

    @property
    def question_ids(self):
        """Gets the question_ids of this UpdateQuestionnaireRequest.  # noqa: E501


        :return: The question_ids of this UpdateQuestionnaireRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._question_ids

    @question_ids.setter
    def question_ids(self, question_ids):
        """Sets the question_ids of this UpdateQuestionnaireRequest.


        :param question_ids: The question_ids of this UpdateQuestionnaireRequest.  # noqa: E501
        :type: list[str]
        """
        if question_ids is None:
            raise ValueError("Invalid value for `question_ids`, must not be `None`")  # noqa: E501

        self._question_ids = question_ids

    @property
    def questionnaire_details(self):
        """Gets the questionnaire_details of this UpdateQuestionnaireRequest.  # noqa: E501


        :return: The questionnaire_details of this UpdateQuestionnaireRequest.  # noqa: E501
        :rtype: UpdateQuestionnaireRequestQuestionnaireDetails
        """
        return self._questionnaire_details

    @questionnaire_details.setter
    def questionnaire_details(self, questionnaire_details):
        """Sets the questionnaire_details of this UpdateQuestionnaireRequest.


        :param questionnaire_details: The questionnaire_details of this UpdateQuestionnaireRequest.  # noqa: E501
        :type: UpdateQuestionnaireRequestQuestionnaireDetails
        """
        if questionnaire_details is None:
            raise ValueError("Invalid value for `questionnaire_details`, must not be `None`")  # noqa: E501

        self._questionnaire_details = questionnaire_details

    @property
    def date_created(self):
        """Gets the date_created of this UpdateQuestionnaireRequest.  # noqa: E501

        Date when the questionnaire is created.  # noqa: E501

        :return: The date_created of this UpdateQuestionnaireRequest.  # noqa: E501
        :rtype: int
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this UpdateQuestionnaireRequest.

        Date when the questionnaire is created.  # noqa: E501

        :param date_created: The date_created of this UpdateQuestionnaireRequest.  # noqa: E501
        :type: int
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def last_updated(self):
        """Gets the last_updated of this UpdateQuestionnaireRequest.  # noqa: E501

        Date when the questionnaire is updated.  # noqa: E501

        :return: The last_updated of this UpdateQuestionnaireRequest.  # noqa: E501
        :rtype: int
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this UpdateQuestionnaireRequest.

        Date when the questionnaire is updated.  # noqa: E501

        :param last_updated: The last_updated of this UpdateQuestionnaireRequest.  # noqa: E501
        :type: int
        """
        if last_updated is None:
            raise ValueError("Invalid value for `last_updated`, must not be `None`")  # noqa: E501

        self._last_updated = last_updated

    @property
    def questions(self):
        """Gets the questions of this UpdateQuestionnaireRequest.  # noqa: E501

        All questions in this list.  # noqa: E501

        :return: The questions of this UpdateQuestionnaireRequest.  # noqa: E501
        :rtype: list[UpdateQuestionnaireRequestQuestions]
        """
        return self._questions

    @questions.setter
    def questions(self, questions):
        """Sets the questions of this UpdateQuestionnaireRequest.

        All questions in this list.  # noqa: E501

        :param questions: The questions of this UpdateQuestionnaireRequest.  # noqa: E501
        :type: list[UpdateQuestionnaireRequestQuestions]
        """
        if questions is None:
            raise ValueError("Invalid value for `questions`, must not be `None`")  # noqa: E501

        self._questions = questions

    @property
    def locales(self):
        """Gets the locales of this UpdateQuestionnaireRequest.  # noqa: E501


        :return: The locales of this UpdateQuestionnaireRequest.  # noqa: E501
        :rtype: list[UpdateQuestionnaireRequestLocales]
        """
        return self._locales

    @locales.setter
    def locales(self, locales):
        """Sets the locales of this UpdateQuestionnaireRequest.


        :param locales: The locales of this UpdateQuestionnaireRequest.  # noqa: E501
        :type: list[UpdateQuestionnaireRequestLocales]
        """
        if locales is None:
            raise ValueError("Invalid value for `locales`, must not be `None`")  # noqa: E501

        self._locales = locales

    @property
    def recruiter_user_id(self):
        """Gets the recruiter_user_id of this UpdateQuestionnaireRequest.  # noqa: E501

        User id of the recruiter.  # noqa: E501

        :return: The recruiter_user_id of this UpdateQuestionnaireRequest.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_user_id

    @recruiter_user_id.setter
    def recruiter_user_id(self, recruiter_user_id):
        """Sets the recruiter_user_id of this UpdateQuestionnaireRequest.

        User id of the recruiter.  # noqa: E501

        :param recruiter_user_id: The recruiter_user_id of this UpdateQuestionnaireRequest.  # noqa: E501
        :type: str
        """
        if recruiter_user_id is None:
            raise ValueError("Invalid value for `recruiter_user_id`, must not be `None`")  # noqa: E501

        self._recruiter_user_id = recruiter_user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateQuestionnaireRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateQuestionnaireRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    candidates-api-activities

    The Note APIs allows you to Add, Get, Update and Delete Notes.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class CandidateNotesApi(object):
    base_path = "/candidates-api/activities"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def add_notes(self, body, candidate_id, **kwargs):  # noqa: E501
        """Add Note  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_notes(body, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddNotes body: Add notes to candidates. (required)
        :param str candidate_id: Unique identifier for the Candidate. (required)
        :param str x_ph_user_id:
        :return: CreateNoteSuccess
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_notes_with_http_info(body, candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_notes_with_http_info(body, candidate_id, **kwargs)  # noqa: E501
            return data

    def add_notes_with_http_info(self, body, candidate_id, **kwargs):  # noqa: E501
        """Add Note  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_notes_with_http_info(body, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddNotes body: Add notes to candidates. (required)
        :param str candidate_id: Unique identifier for the Candidate. (required)
        :param str x_ph_user_id:
        :return: CreateNoteSuccess
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'candidate_id', 'x_ph_user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_notes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `add_notes`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `add_notes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/notes', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateNoteSuccess',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_notes(self, candidate_id, note_id, x_ph_userid, **kwargs):  # noqa: E501
        """Delete Note  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_notes(candidate_id, note_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Unique Identifier for the candidate. (required)
        :param str note_id: Unique Identifier for the note. (required)
        :param str x_ph_userid: (required)
        :return: DeleteNoteSuccess
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_notes_with_http_info(candidate_id, note_id, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_notes_with_http_info(candidate_id, note_id, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def delete_notes_with_http_info(self, candidate_id, note_id, x_ph_userid, **kwargs):  # noqa: E501
        """Delete Note  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_notes_with_http_info(candidate_id, note_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Unique Identifier for the candidate. (required)
        :param str note_id: Unique Identifier for the note. (required)
        :param str x_ph_userid: (required)
        :return: DeleteNoteSuccess
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['candidate_id', 'note_id', 'x_ph_userid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_notes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `delete_notes`")  # noqa: E501
        # verify the required parameter 'note_id' is set
        if ('note_id' not in params or
                params['note_id'] is None):
            raise ValueError("Missing the required parameter `note_id` when calling `delete_notes`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `delete_notes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501
        if 'note_id' in params:
            path_params['noteId'] = params['note_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/notes/{noteId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteNoteSuccess',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_candidate_job_notes(self, x_ph_user_id, job_id, candidate_id, **kwargs):  # noqa: E501
        """Get Candidate Job Notes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_job_notes(x_ph_user_id, job_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_user_id: (required)
        :param str job_id: (required)
        :param str candidate_id: (required)
        :return: GetCandidateJobNotes
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_candidate_job_notes_with_http_info(x_ph_user_id, job_id, candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_candidate_job_notes_with_http_info(x_ph_user_id, job_id, candidate_id, **kwargs)  # noqa: E501
            return data

    def get_candidate_job_notes_with_http_info(self, x_ph_user_id, job_id, candidate_id, **kwargs):  # noqa: E501
        """Get Candidate Job Notes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_job_notes_with_http_info(x_ph_user_id, job_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_user_id: (required)
        :param str job_id: (required)
        :param str candidate_id: (required)
        :return: GetCandidateJobNotes
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_ph_user_id', 'job_id', 'candidate_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_candidate_job_notes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `get_candidate_job_notes`")  # noqa: E501
        # verify the required parameter 'job_id' is set
        if ('job_id' not in params or
                params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `get_candidate_job_notes`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_candidate_job_notes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']  # noqa: E501
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/jobs/{jobId}/candidates/{candidateId}/notes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetCandidateJobNotes',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_notes(self, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Get Notes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_notes(x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_user_id: (required)
        :param str candidate_id: (required)
        :param int _from: The number of notes to skip before starting to collect the result.
        :param int size: size of the result.
        :param str request_type: requestType of the notes.
        :param str recruiter_email: email of the recruiter.
        :param bool include_private_notes: Boolean flag to check whether to include private notes.
        :return: FetchCandidateNotes
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_notes_with_http_info(x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_notes_with_http_info(x_ph_user_id, candidate_id, **kwargs)  # noqa: E501
            return data

    def get_notes_with_http_info(self, x_ph_user_id, candidate_id, **kwargs):  # noqa: E501
        """Get Notes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_notes_with_http_info(x_ph_user_id, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_user_id: (required)
        :param str candidate_id: (required)
        :param int _from: The number of notes to skip before starting to collect the result.
        :param int size: size of the result.
        :param str request_type: requestType of the notes.
        :param str recruiter_email: email of the recruiter.
        :param bool include_private_notes: Boolean flag to check whether to include private notes.
        :return: FetchCandidateNotes
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_ph_user_id', 'candidate_id', '_from', 'size', 'request_type', 'recruiter_email', 'include_private_notes']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_notes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `get_notes`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_notes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'size' in params:
            query_params.append(('size', params['size']))  # noqa: E501
        if 'request_type' in params:
            query_params.append(('requestType', params['request_type']))  # noqa: E501
        if 'recruiter_email' in params:
            query_params.append(('recruiterEmail', params['recruiter_email']))  # noqa: E501
        if 'include_private_notes' in params:
            query_params.append(('includePrivateNotes', params['include_private_notes']))  # noqa: E501

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/notes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FetchCandidateNotes',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_notes(self, body, x_ph_userid, candidate_id, note_id, **kwargs):  # noqa: E501
        """Update Note  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_notes(body, x_ph_userid, candidate_id, note_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateCandidateNote body: update CandidateNote (required)
        :param str x_ph_userid: (required)
        :param str candidate_id: (required)
        :param str note_id: (required)
        :return: SuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_notes_with_http_info(body, x_ph_userid, candidate_id, note_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_notes_with_http_info(body, x_ph_userid, candidate_id, note_id, **kwargs)  # noqa: E501
            return data

    def update_notes_with_http_info(self, body, x_ph_userid, candidate_id, note_id, **kwargs):  # noqa: E501
        """Update Note  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_notes_with_http_info(body, x_ph_userid, candidate_id, note_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateCandidateNote body: update CandidateNote (required)
        :param str x_ph_userid: (required)
        :param str candidate_id: (required)
        :param str note_id: (required)
        :return: SuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_userid', 'candidate_id', 'note_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_notes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_notes`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `update_notes`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `update_notes`")  # noqa: E501
        # verify the required parameter 'note_id' is set
        if ('note_id' not in params or
                params['note_id'] is None):
            raise ValueError("Missing the required parameter `note_id` when calling `update_notes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501
        if 'note_id' in params:
            path_params['noteId'] = params['note_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/notes/{noteId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa
"""
    campaigns-email

    These APIs ensures an easy integration process of Email management for developers to send, read, and track Email campaigns within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.campaignsemail.models.api_error import ApiError
from phenom.api.campaignsemail.models.api_link import ApiLink
from phenom.api.campaignsemail.models.bad_request import BadRequest
from phenom.api.campaignsemail.models.email_campaign_activity import EmailCampaignActivity
from phenom.api.campaignsemail.models.email_campaign_activity_data import EmailCampaignActivityData
from phenom.api.campaignsemail.models.email_campaign_activity_pagination import EmailCampaignActivityPagination
from phenom.api.campaignsemail.models.email_campaign_history import EmailCampaignHistory
from phenom.api.campaignsemail.models.email_campaign_history_data import EmailCampaignHistoryData
from phenom.api.campaignsemail.models.email_campaign_history_pagination import EmailCampaignHistoryPagination
from phenom.api.campaignsemail.models.email_campaign_opt_in import EmailCampaignOptIn
from phenom.api.campaignsemail.models.email_campaign_opt_in_details import EmailCampaignOptInDetails
from phenom.api.campaignsemail.models.email_campaign_opt_in_history import EmailCampaignOptInHistory
from phenom.api.campaignsemail.models.email_campaign_opt_in_history_details import EmailCampaignOptInHistoryDetails
from phenom.api.campaignsemail.models.email_campaign_opt_in_history_details_content import EmailCampaignOptInHistoryDetailsContent
from phenom.api.campaignsemail.models.email_campaign_opt_in_history_details_pageable import EmailCampaignOptInHistoryDetailsPageable
from phenom.api.campaignsemail.models.email_campaign_opt_in_history_details_pageable_sort import EmailCampaignOptInHistoryDetailsPageableSort
from phenom.api.campaignsemail.models.email_campaign_opt_in_request import EmailCampaignOptInRequest
from phenom.api.campaignsemail.models.email_campaign_opt_in_response import EmailCampaignOptInResponse
from phenom.api.campaignsemail.models.email_campaign_opt_in_response_details import EmailCampaignOptInResponseDetails
from phenom.api.campaignsemail.models.internal_server_error import InternalServerError
from phenom.api.campaignsemail.models.send_email_campaign_request import SendEmailCampaignRequest
from phenom.api.campaignsemail.models.send_email_campaign_response import SendEmailCampaignResponse
from phenom.api.campaignsemail.models.send_email_campaign_response_data import SendEmailCampaignResponseData
from phenom.api.campaignsemail.models.unauthorized_request import UnauthorizedRequest



# coding: utf-8

"""
    evaluation-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CandidateEvaluationsOnJobDataFormFeedback(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'login_user_name': 'str',
        'created_date': 'str',
        'rating': 'str',
        'recommendation': 'str'
    }

    attribute_map = {
        'login_user_name': 'loginUserName',
        'created_date': 'createdDate',
        'rating': 'rating',
        'recommendation': 'recommendation'
    }

    def __init__(self, login_user_name=None, created_date=None, rating=None, recommendation=None):  # noqa: E501
        """CandidateEvaluationsOnJobDataFormFeedback - a model defined in Swagger"""  # noqa: E501
        self._login_user_name = None
        self._created_date = None
        self._rating = None
        self._recommendation = None
        self.discriminator = None
        if login_user_name is not None:
            self.login_user_name = login_user_name
        if created_date is not None:
            self.created_date = created_date
        if rating is not None:
            self.rating = rating
        if recommendation is not None:
            self.recommendation = recommendation

    @property
    def login_user_name(self):
        """Gets the login_user_name of this CandidateEvaluationsOnJobDataFormFeedback.  # noqa: E501

        Evaluation given user name.  # noqa: E501

        :return: The login_user_name of this CandidateEvaluationsOnJobDataFormFeedback.  # noqa: E501
        :rtype: str
        """
        return self._login_user_name

    @login_user_name.setter
    def login_user_name(self, login_user_name):
        """Sets the login_user_name of this CandidateEvaluationsOnJobDataFormFeedback.

        Evaluation given user name.  # noqa: E501

        :param login_user_name: The login_user_name of this CandidateEvaluationsOnJobDataFormFeedback.  # noqa: E501
        :type: str
        """

        self._login_user_name = login_user_name

    @property
    def created_date(self):
        """Gets the created_date of this CandidateEvaluationsOnJobDataFormFeedback.  # noqa: E501

        Evaluation given date.  # noqa: E501

        :return: The created_date of this CandidateEvaluationsOnJobDataFormFeedback.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this CandidateEvaluationsOnJobDataFormFeedback.

        Evaluation given date.  # noqa: E501

        :param created_date: The created_date of this CandidateEvaluationsOnJobDataFormFeedback.  # noqa: E501
        :type: str
        """

        self._created_date = created_date

    @property
    def rating(self):
        """Gets the rating of this CandidateEvaluationsOnJobDataFormFeedback.  # noqa: E501

        Evaluation rating.  # noqa: E501

        :return: The rating of this CandidateEvaluationsOnJobDataFormFeedback.  # noqa: E501
        :rtype: str
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        """Sets the rating of this CandidateEvaluationsOnJobDataFormFeedback.

        Evaluation rating.  # noqa: E501

        :param rating: The rating of this CandidateEvaluationsOnJobDataFormFeedback.  # noqa: E501
        :type: str
        """

        self._rating = rating

    @property
    def recommendation(self):
        """Gets the recommendation of this CandidateEvaluationsOnJobDataFormFeedback.  # noqa: E501

        Evaluation recommendation.  # noqa: E501

        :return: The recommendation of this CandidateEvaluationsOnJobDataFormFeedback.  # noqa: E501
        :rtype: str
        """
        return self._recommendation

    @recommendation.setter
    def recommendation(self, recommendation):
        """Sets the recommendation of this CandidateEvaluationsOnJobDataFormFeedback.

        Evaluation recommendation.  # noqa: E501

        :param recommendation: The recommendation of this CandidateEvaluationsOnJobDataFormFeedback.  # noqa: E501
        :type: str
        """

        self._recommendation = recommendation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CandidateEvaluationsOnJobDataFormFeedback, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CandidateEvaluationsOnJobDataFormFeedback):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
